@@ -54,10 +54,10 @@ if [ $exitflag -ne 0 ]; then
 	exit
 fi
 # All looks ok - we can now mount the target directory
-mount -t ext2 $TARGET_DISK$TARGET_PART $TARGET_MOUNT || \
-  err_quit "Failed to mount $TARGET_DISK$TARGET_PART on $TARGET_MOUNT as an ext2 partition"
+mount $TARGET_DISK$TARGET_PART $TARGET_MOUNT || \
+  err_quit "Failed to mount $TARGET_DISK$TARGET_PART on $TARGET_MOUNT. "
 
-# Mount Ok - Parition correct now set ext2 label to ROOT_FS
+# Mount Ok - Parition correct now set label to ROOT_FS
 e2label $TARGET_DISK$TARGET_PART ROOT_FS
 
 # We are going to use rsync to copy files from the distribution to the
@@ -94,6 +94,7 @@ update_inittab "$DISTDIR" "$TARGET_MOUNT"
 update_pcmcia "$TARGET_MOUNT"
 remove_dnsmasq_pxe "$TARGET_MOUNT"
 reconfig_resolvconf "$TARGET_MOUNT"
+update_hosts "$TARGET_MOUNT"
 ${EXECDIR}/setboot.sh
 write_config "$TARGET_MOUNT/etc/voyage.conf" "$VOYAGE_CONF_LIST"
 umount $TARGET_MOUNT
