@@ -3,9 +3,10 @@
  *
  * hardware.html functions
  *
- * Copyright (C) 2006-2008, Digium, Inc.
+ * Copyright (C) 2006-2011, Digium, Inc.
  *
  * Pari Nannapaneni <pari@digium.com>
+ * Erin Spiceland <espiceland@digium.com>
  *
  * See http://www.asterisk.org for more information about
  * the Asterisk project. Please do not directly contact
@@ -729,8 +730,8 @@ var applySettings = {
 		u.callActions();
 		u.clearActions();
 	
-		ASTGUI.dialog.waitWhile('updating modprobe.conf ...');
-		var cmd1 = "cp /etc/asterisk/modprobe_default /etc/modprobe.conf";
+		ASTGUI.dialog.waitWhile('updating modprobe configuration ...');
+		var cmd1 = "cp /etc/asterisk/modprobe_default /etc/modprobe.d/dahdi.conf";
 		var params = "options " + ASTGUI.getFieldValue('zap_moduleName') ;
 
 		if( _$('enable_disable_checkbox_opermode').checked ){
@@ -780,7 +781,7 @@ var applySettings = {
 			}
 		}
 	
-		var cmd2 = "echo \"" + params + "\" >> /etc/modprobe.conf ";
+		var cmd2 = "echo \"" + params + "\" >> /etc/modprobe.d/dahdi.conf ";
 	
 		var update_usersConf = function(){
 			// update MWI settings in users.conf
@@ -964,8 +965,8 @@ var applySettings = {
 
 		for( var e in fxx ){ if(fxx.hasOwnProperty(e)){	x.new_action('append', context, e, fxx[e]);	}}
 
-		if(bchanstring.strip()){ x.new_action('append', context, 'bchan', bchanstring); }
-		if(dchanstring.strip()){ x.new_action('append', context, 'dchan', dchanstring); }
+		if(bchanstring.trim()){ x.new_action('append', context, 'bchan', bchanstring); }
+		if(dchanstring.trim()){ x.new_action('append', context, 'dchan', dchanstring); }
 
 		// write back any actual analog ports
 		parent.sessionData.PORTS_SIGNALLING.ls = []; // reset previous signalling data
