@@ -3,10 +3,11 @@
  *
  * hardware_dahdi.html functions
  *
- * Copyright (C) 2006-2009, Digium, Inc.
+ * Copyright (C) 2006-2011, Digium, Inc.
  *
  * Pari Nannapaneni <pari@digium.com>
  * Ryan Brindley <ryan@digium.com>
+ * Erin Spiceland <espiceland@digium.com>
  *
  * See http://www.asterisk.org for more information about
  * the Asterisk project. Please do not directly contact
@@ -132,14 +133,11 @@ var detectHwChanges = function(){ // compare DETECTEDHARDWARE vs CONFIGUREDHARDW
 	if(configured_devices.length == detected_devices.length){
 		for(var l=0; l < configured_devices.length; l++){
 			if(configured_devices[l] != detected_devices[l]){ // devices does not match - but the number of devices match
-				top.log.debug("DEVICES or basechans does not MATCHED");
 				return true;
 			}
 		}
-		top.log.debug("DEVICES and basechans MATCH");
 		return false;
 	}else{	
-		top.log.debug("DEVICES or basechans does not MATCHED");
 		return true;
 	}
 };
@@ -268,6 +266,13 @@ var editSPAN = function(l){ // show values for SPAN l in the edit_span dialog bo
 		_$('editspan_switchtype').selectedIndex = -1 ;
 	}
 
+	if(SPANS[l]['pridialplan']) {
+		ASTGUI.selectbox.selectOption( _$('editspan_pridialplan'), SPANS[l]['pridialplan']);
+	}
+	if(SPANS[l]['prilocaldialplan']) {
+		ASTGUI.selectbox.selectOption( _$('editspan_prilocaldialplan'), SPANS[l]['prilocaldialplan']);
+	}
+
 	(function (){
 		ASTGUI.selectbox.clear( _$('editspan_syncsrc'));
 		var y = SPANCOUNT_LOCATION[ SPANS[l]['location'] ];
@@ -388,7 +393,6 @@ var loadConfigFiles = {
 	//   check if the channels in zapchan are within max and min
 	//   if yes then set the current range values
 	load_hwcfgfile: function(){ // read hwcfgfile (if exists) into CONFIGUREDHARDWARE 
-		top.log.debug("load last configured hardware information, start function: loadConfigFiles.load_hwcfgfile()");
 		var n = config2json({filename:hwcfgfile, usf:1});
 		if( n.getOwnProperties().length == 0 ){ // if file not found or no previous hardware detected
 				hwchanged = -1;
@@ -404,23 +408,19 @@ var loadConfigFiles = {
 			}}
 			loadConfigFiles.run_detectdahdi();
 		}
-		top.log.debug("end of function: loadConfigFiles.load_hwcfgfile()");
 	},
 
 	run_detectdahdi: function(){
-		top.log.debug("start function: loadConfigFiles.run_detectdahdi()");
 
 		ASTGUI.miscFunctions.createConfig( 'applyzap.conf', function(){
 			parent.ASTGUI.systemCmd( top.sessionData.directories.app_DahdiScan , function(){ // run ztscan and then try loading ztscan.conf
 				window.setTimeout( loadConfigFiles.read_DahdiScanConf , 700 ); // leave some time for ztscan to generate ztscan.conf
 			});
-			top.log.debug("end of function: loadConfigFiles.run_detectdahdi()");
 		});
 	},
 
 	//readZtscanConf: function(){
 	read_DahdiScanConf: function(){
-		top.log.debug("start function: loadConfigFiles.read_DahdiScanConf()");
 		var ztsc = $.ajax({ url: ASTGUI.paths.rawman+'?action=getconfig&filename=' + ASTGUI.globals.dahdiScanOutput , async: false }).responseText;
 		var ztsc_Lower = ztsc.toLowerCase();
 		if( ztsc_Lower.contains('response: error') && ztsc_Lower.contains('message: config file not found') ){
@@ -443,6 +443,7 @@ var loadConfigFiles = {
 				continue;
 			} // in this page, we care only about digital spans 
 			//  note: function detectHwChanges checks if there are any changes in analog ports detected
+			top.log.debug("devicetype is " + n[l]['devicetype']);
 			if(  n[l]['description'].toLowerCase().contains('ztdummy') ){ continue;} // ignore ztdummy :-)
 			SPANS[l] = {};
 			for( var k in n[l] ){ if(n[l].hasOwnProperty(k)){ 
@@ -504,12 +505,10 @@ var loadConfigFiles = {
 			}}
 		}}
 		if(hwchanged != -1){ hwchanged = detectHwChanges(); }
-		top.log.debug("end of function: loadConfigFiles.read_DahdiScanConf()");
 		loadConfigFiles.readUsersConf(); // read span_x (where T1/E1 trunks are defined)
 	},
 
 	readUsersConf: function(){
-		top.log.debug("start function: loadConfigFiles.readUsersConf()");
 
 		var usrs = $.ajax({ url: ASTGUI.paths.rawman+'?action=getconfig&filename=users.conf', async: false }).responseText;
 		var usrs_Lower = usrs.toLowerCase();
@@ -582,12 +581,10 @@ var loadConfigFiles = {
 				}
 			}}
 		})();
-		top.log.debug("end of function: loadConfigFiles.readUsersConf()");
 		showtable();
 	},
 
 	load_zaptel_conf: function(){
-		top.log.debug("start function: loadConfigFiles.load_zaptel_conf()");
 		// we parse zaptel.conf to get the loadzone and syncsrc for each span
 		var tmp_file = ASTGUI.globals.dahdiIncludeFile ;
 		var parseZaptelconf = function(zp){
@@ -673,7 +670,6 @@ var loadConfigFiles = {
 				parseZaptelconf(q);
 			}
 		}
-		top.log.debug("end of function: loadConfigFiles.load_zaptel_conf()");
 	}
 };
 
@@ -736,6 +732,8 @@ var updateSpanInfo = function(){
 	SPANS[b]['switchtype'] = _$('editspan_switchtype').value;
 	SPANS[b]['syncsrc'] = _$('editspan_syncsrc').value;
 	SPANS[b]['lbo'] = _$('editspan_lbo').value;
+	SPANS[b]['pridialplan'] = _$('editspan_pridialplan').value;
+	SPANS[b]['prilocaldialplan'] = _$('editspan_prilocaldialplan').value;
 
 	_$('row'+ b).style.background = "#C9AAAA";
 
@@ -788,121 +786,121 @@ var applySettings = {
 	},
 
 	saveOpermodeSettings: function() {
-		ASTGUI.dialog.waitWhile('saving...');
+ 		ASTGUI.dialog.waitWhile('updating modprobe configuration ...');
 		var u = new listOfSynActions(ASTGUI.globals.configfile);
+ 		var module_name = $('#zap_moduleName').val();
+ 		var params = "options " + module_name;
+ 		var params_to_delete = params;
 
 		/* ok, lets update the configfile is the values are set */
 		if ($('#enable_disable_checkbox_opermode:checked').val() != null) {
-			u.new_action('update', 'general', 'opermode', $('#opermode').val());
+ 			var h = $('#opermode').val();
+ 			u.new_action('update', 'general', 'opermode', h);
+ 			if(h){ params += " opermode=" + h; }
+ 		}else{
+ 			u.new_action('delete', 'general', 'opermode', '');
 		}
 
 		if ($('#enable_disable_checkbox_alawoverride:checked').val() != null){
-			u.new_action('update', 'general', 'alawoverride', $('#alawoverride').val());
+ 			h = $('#alawoverride').val();
+ 			u.new_action('update', 'general', 'alawoverride', h);
+ 			if(h){ params += " alawoverride=" + h; }
+ 		}else{
+ 			u.new_action('delete', 'general', 'alawoverride', '');
 		}
 
 		if( $('#enable_disable_checkbox_fxshonormode:checked').val() != null ){
-			u.new_action('update', 'general', 'fxshonormode', $('#fxshonormode').val());
+ 			h = $('#fxshonormode').val();
+ 			u.new_action('update', 'general', 'fxshonormode', h);
+ 			if(h){ params += " fxshonormode=" + h; }
+ 		}else{
+ 			u.new_action('delete', 'general', 'fxshonormode', '');
 		}
 
 		if( $('#enable_disable_checkbox_boostringer:checked').val() != null ){
-			u.new_action('update', 'general', 'boostringer', $('#boostringer').val());
+ 			h = $('#boostringer').val();
+ 			u.new_action('update', 'general', 'boostringer', h);
+ 			if(h){ params += " boostringer=" + h; }
+ 		}else{
+ 			u.new_action('delete', 'general', 'boostringer', '');
 		}
 
-		u.new_action('update', 'general', 'ZAPMODULE_NAME', $('#zap_moduleName').val());
+ 		u.new_action('update', 'general', 'ZAPMODULE_NAME', module_name);
 		u.callActions();
 		u.clearActions();
 
 		if( $('#enable_disable_checkbox_mwimode:checked').val() != null ){
 			u.new_action('update', 'general', 'mwimode', $('#mwimode').val());
 			if( ASTGUI.getFieldValue('mwimode') == 'NEON' ){
-				u.new_action('update', 'general', 'neonmwi_level', $('#neonmwi_level').val());
-				u.new_action('update', 'general', 'neonmwi_offlimit', $('#neonmwi_offlimit').val());
+ 				params += " neonmwi_monitor=1";
+ 				h = $('#neonmwi_level').val();
+ 				if(h){
+ 					params += ' neonmwi_level=' + h;
+ 					u.new_action('update', 'general', 'neonmwi_level', h);
+ 				}else{
+ 					u.new_action('delete', 'general', 'neonmwi_level', '');
+ 				}
+ 
+ 				h = $('#neonmwi_offlimit').val();
+ 				if(h){
+ 					params += ' neonmwi_offlimit=' + h;
+ 					u.new_action('update', 'general', 'neonmwi_offlimit', h);
+ 				}else{
+ 					u.new_action('delete', 'general', 'neonmwi_offlimit', '');
+ 				}
+ 			}else{
+ 				params += " neonmwi_monitor=0";
 			}
+ 		}else{
+ 			u.new_action('delete', 'general', 'mwimode', '');
 		}
 
 		if( $('#enable_disable_checkbox_lowpower:checked').val() != null ){
-			u.new_action('update', 'general', 'lowpower', $('#lowpower').val());
-		}
-
-		if( $('#enable_disable_checkbox_fastringer:checked').val() != null ){
-			u.new_action('update', 'general', 'fastringer', $('#fastringer').val());
-		}
-
-		if( $('#enable_disable_checkbox_fwringdetect:checked').val() != null ){
-			u.new_action('update', 'general', 'fwringdetect', $('#fwringdetect').val());
-		}
-
-		u.new_action('update', 'general', 'vpmnlptype', $('#vpmnlptype').val());
-		u.new_action('update', 'general', 'vpmnlpthresh', $('#vpmnlpthresh').val());
-		u.new_action('update', 'general', 'vpmnlpmaxsupp', $('#vpmnlpmaxsupp').val());
-
-		u.callActions();
-		u.clearActions();
-	
-		ASTGUI.dialog.waitWhile('updating modprobe.conf ...');
-		var cmd1 = "cp /etc/asterisk/modprobe_default /etc/modprobe.conf";
-		var params = "options " + $('#zap_moduleName').val();
-
-		if( $('#enable_disable_checkbox_opermode:checked').val() !== null ){
-			var h = $('#opermode').val();
-				if(h){ params += " opermode=" + h; }
-		}
-
-		if( _$('enable_disable_checkbox_alawoverride').checked ){
-			h = $('#alawoverride').val();
-			if(h){ params += " alawoverride=" + h; }
-		}
-
-		if( _$('enable_disable_checkbox_fxshonormode').checked ){
-		h = $('#fxshonormode').val();
-			if(h){ params += " fxshonormode=" + h; }
-		}
-
-		if( _$('enable_disable_checkbox_boostringer').checked ){
-			h = $('#boostringer').val();
-			if(h){ params += " boostringer=" + h; }
-		}
-
-		if( _$('enable_disable_checkbox_lowpower').checked ){
 			h = $('#lowpower').val();
+ 			u.new_action('update', 'general', 'lowpower', h);
 			if(h){ params += " lowpower=" + h; }
+ 		}else{
+ 			u.new_action('delete', 'general', 'lowpower', '');
 		}
 
-		if( _$('enable_disable_checkbox_fastringer').checked ){
+ 		if( $('#enable_disable_checkbox_fastringer:checked').val() != null ){
 			h = $('#fastringer').val();
+ 			u.new_action('update', 'general', 'fastringer', h);
 			if(h){ params += " fastringer=" + h; }
+ 		}else{
+ 			u.new_action('delete', 'general', 'fastringer', '');
 		}
 
-		if( _$('enable_disable_checkbox_fwringdetect').checked ){
+ 		if( $('#enable_disable_checkbox_fwringdetect:checked').val() != null ){
 			h = $('#fwringdetect').val();
+ 			u.new_action('update', 'general', 'fwringdetect', h);
 			if(h == '1'){ params += " fwringdetect=" + h; }
-		}
-
-		if( _$('enable_disable_checkbox_mwimode').checked ){
-			if( $('#mwimode').val()== 'NEON'){
-				params += " neonmwi_monitor=1";
-				var h = $('#neonmwi_level').val();
-				if(h){ params += ' neonmwi_level=' + h ; }
-				var h = $('#neonmwi_offlimit').val();
-				if(h){ params += ' neonmwi_offlimit=' + h ; }
-			}else{
-				params += " neonmwi_monitor=0";
-			}
+ 		}else{
+ 			u.new_action('delete', 'general', 'fwringdetect', '');
 		}
 
 		h = ASTGUI.getFieldValue('vpmnlptype') ;
-			if(h){ params += " vpmnlptype=" + h; }
+ 		if(h){ params += " vpmnlptype=" + h; }
+ 		u.new_action('update', 'general', 'vpmnlptype', h);
+
 		h = ASTGUI.getFieldValue('vpmnlpthresh') ;
-			if(h){ params += " vpmnlpthresh=" + h; }
+ 		if(h){ params += " vpmnlpthresh=" + h; }
+ 		u.new_action('update', 'general', 'vpmnlpthresh', h);
+ 
 		h = ASTGUI.getFieldValue('vpmnlpmaxsupp');
-			if(h){ params += " vpmnlpmaxsupp=" + h; }
+ 		if(h){ params += " vpmnlpmaxsupp=" + h; }
+ 		u.new_action('update', 'general', 'vpmnlpmaxsupp', h);
+ 
+ 		u.callActions();
+ 		u.clearActions();
+  	
 	
-		var cmd2 = "echo \"" + params + "\" >> /etc/modprobe.conf ";
+		var cmd2 = "grep -v \"^" + params_to_delete + "\" /etc/modprobe.d/dahdi.conf > /etc/modprobe.d/dahdi.conf ; echo \"" + params + "\" >> /etc/modprobe.d/dahdi.conf ";
 	
 		var update_usersConf = function(){
 			// update MWI settings in users.conf
 			var u = new listOfSynActions('users.conf');
-			if( $('#enable_disable_checkbox_mwimode:checked').val() !== null ){
+			if( $('#enable_disable_checkbox_mwimode:checked').val() != null ){
 				if( $('#mwimode').val()== 'FSK'){
 					u.new_action('update', 'general' , 'mwimonitor', 'fsk');
 					u.new_action('update', 'general' , 'mwilevel', '512');
@@ -928,11 +926,9 @@ var applySettings = {
 			return;
 		}
 
-		ASTGUI.systemCmd( cmd1, function(){ 
-			ASTGUI.systemCmd( cmd2, function(){ 
-				ASTGUI.dialog.waitWhile('updating Analog Trunks with MWI settings ...');
-				update_usersConf();
-			});
+		ASTGUI.systemCmd( cmd2, function(){ 
+			ASTGUI.dialog.waitWhile('updating Analog Trunks with MWI settings ...');
+			update_usersConf();
 		});
 		
 	},
@@ -990,6 +986,10 @@ var applySettings = {
 				pri_trunk['hassip'] = 'no';
 			x.new_action('update', d , "hasiax", 'no');
 				pri_trunk['hasiax'] = 'no';
+			x.new_action('update', d , "pridialplan", SPANS[k]['pridialplan']);
+				pri_trunk['pridialplan'] = SPANS[k]['pridialplan'];
+			x.new_action('update', d , "prilocaldialplan", SPANS[k]['prilocaldialplan']);
+				pri_trunk['prilocaldialplan'] = SPANS[k]['prilocaldialplan'];
 
 			if ( !SPANS[k]['signalling'].beginsWith('fxo') ){ 
 				// we do not want a context to be set for user stations
@@ -1075,9 +1075,9 @@ var applySettings = {
 
 		for( var e in fxx ){ if(fxx.hasOwnProperty(e)){	x.new_action('append', context, e, fxx[e]);	}}
 
-		if(bchanstring.strip()){ x.new_action('append', context, 'bchan', bchanstring); }
-		if(dchanstring.strip()){ x.new_action('append', context, 'dchan', dchanstring); }
-		if(hardhdlc.strip()){ x.new_action('append', context, 'hardhdlc', hardhdlc); }
+		if(bchanstring.trim()){ x.new_action('append', context, 'bchan', bchanstring); }
+		if(dchanstring.trim()){ x.new_action('append', context, 'dchan', dchanstring); }
+		if(hardhdlc.trim()){ x.new_action('append', context, 'hardhdlc', hardhdlc); }
 
 		// write back any actual analog ports
 		parent.sessionData.PORTS_SIGNALLING.ls = []; // reset previous signalling data
@@ -1176,7 +1176,6 @@ var applyDigitalSettings = function(){
 
 
 var localajaxinit = function(){
-	top.log.debug("Starting Loading Page digital.html .. start function: window.onload()");
 	portsSignalling = ASTGUI.cloneObject(parent.sessionData.PORTS_SIGNALLING);
 
 	ASTGUI.dialog.waitWhile('Detecting Analog/Digital Hardware ...');
@@ -1270,10 +1269,38 @@ var localajaxinit = function(){
 	ASTGUI.updateFieldToValue('mwimode', config.getProperty('mwimode'));
 	_$('enable_disable_checkbox_mwimode').checked = (config.getProperty('mwimode')) ? true : false ;
 	_$('enable_disable_checkbox_mwimode').updateStatus();
-	ASTGUI.updateFieldToValue('vpmnlptype', config.getProperty('vpmnlptype') || '4');
-	ASTGUI.updateFieldToValue('vpmnlpthresh', config.getProperty('vpmnlpthresh') || '24');
-	ASTGUI.updateFieldToValue('vpmnlpmaxsupp', config.getProperty('vpmnlpmaxsupp') || '24');
-	top.log.debug("end of function: window.onload()");
+
+
+
+	var DAHDI_version = "0";
+	ASTGUI.systemCmdWithOutput( 'cat /sys/module/dahdi/version' , function(output){
+		output = output.trim();
+		if(output){
+			DAHDI_version = output;
+		}else{
+			ASTGUI.systemCmdWithOutput( 'modinfo -F version dahdi' , function(output){
+				output = output.trim();
+				if(output){
+					DAHDI_version = output;
+				}
+			});
+		}
+	});
+	ASTGUI.systemCmdWithOutput( 'cat /proc/cmdline' , function(output){
+		if(DAHDI_version.versionGreaterOrEqualTo("2.4.0") || parent.sessionData.PLATFORM.isAA50){
+			ASTGUI.selectbox.append('vpmnlptype', "NLP Suppression", 4);
+			ASTGUI.selectbox.append('vpmnlptype', "NLP AutoSuppression (default)", 6);
+			ASTGUI.updateFieldToValue( 'vpmnlptype' , config.getProperty('vpmnlptype') || '6' );
+			ASTGUI.updateFieldToValue( 'vpmnlpthresh' , config.getProperty('vpmnlpthresh') || '22' );
+			ASTGUI.updateFieldToValue( 'vpmnlpmaxsupp' , config.getProperty('vpmnlpmaxsupp') || '10' );
+		}else{
+			ASTGUI.selectbox.append('vpmnlptype', "NLP Suppression (default)", 4);
+			ASTGUI.updateFieldToValue( 'vpmnlptype' , config.getProperty('vpmnlptype') || '4' );
+			ASTGUI.updateFieldToValue( 'vpmnlpthresh' , config.getProperty('vpmnlpthresh') || '24' );
+			ASTGUI.updateFieldToValue( 'vpmnlpmaxsupp' , config.getProperty('vpmnlpmaxsupp') || '24' );
+		}
+	});
+
 	loadConfigFiles.load_hwcfgfile(); // try to load last detected/configured hardware information
 
 };
