@@ -3,9 +3,10 @@
  *
  * Login functions and other misc functions for index.html
  *
- * Copyright (C) 2006-2008, Digium, Inc.
+ * Copyright (C) 2006-2011, Digium, Inc.
  *
  * Pari Nannapaneni <pari@digium.com>
+ * Erin Spiceland <espiceland@digium.com>
  *
  * See http://www.asterisk.org for more information about
  * the Asterisk project. Please do not directly contact
@@ -71,7 +72,7 @@ var onLogInFunctions = {
 						onLogInFunctions.makePings.stop();
 						top.window.location.replace(top.window.location.href); return true; 
 					}else{
-						top.log.ajax('PING Request: Success');
+						// top.log.ajax('PING Request: Success');
 					}
 				};
 				$.ajax({
@@ -91,13 +92,12 @@ var onLogInFunctions = {
 
 	detectPlatform: function(resp){
 		sessionData.AsteriskVersionString = resp;
+		onLogInFunctions.parseVersion(resp);
 
 		// logic for platform detection, 
 		if( sessionData.PLATFORM.isAA50 || sessionData.PLATFORM.isABE ){
 			if( sessionData.PLATFORM.isAA50 ){
- 				sessionData.PLATFORM.isOSA = false ;
-				sessionData.PLATFORM.isAST_1_4 = false ;
-				sessionData.PLATFORM.isAST_1_6 = false ;
+				sessionData.PLATFORM.isOSA = false ;
 				sessionData.listOfCodecs = {
 					'ulaw' : 'u-law' ,
 					'alaw' : 'a-law' ,
@@ -113,12 +113,9 @@ var onLogInFunctions = {
 			$('div[page="cli.html"]').empty();
 		}else{
 			var resp_lower = resp.toLowerCase();
-			if ( resp_lower.contains("branches/1.6")  || resp_lower.contains("asterisk/1.6") ||  resp_lower.contains("svn-branch-1.6") ||  resp_lower.contains("svn-trunk-")  ){
-				sessionData.PLATFORM.isAST_1_4 = false ;
-				sessionData.PLATFORM.isAST_1_6 = true ;
-				sessionData.PLATFORM.isAST_1_6_1 = resp_lower.contains('1.6.1') ? true : false;
+			if (ASTGUI.version.gteq("1.6.0")){
 				ASTGUI.globals.sbcid_1 = 's,1,ExecIf($[ "${CALLERID(num)}"="" ]?SetCallerPres(unavailable))';
-				ASTGUI.globals.sbcid_2 = 's,1,ExecIf($[ "${CALLERID(num)}"="" ]?Set(CALLERID(all)=unknown <0000000>))';
+				ASTGUI.globals.sbcid_2 = 's,2,ExecIf($[ "${CALLERID(num)}"="" ]?Set(CALLERID(all)=unknown <0000000>))';
 				sessionData.listOfCodecs = { // sessionData.listOfCodecs
 					'ulaw' : 'u-law' ,
 					'alaw' : 'a-law' ,
@@ -134,10 +131,36 @@ var onLogInFunctions = {
 					'h263p': 'H.263p',
 					'h264' : 'H.264'
 				};
-			} else {
-				sessionData.PLATFORM.isAST_1_4 = false ;
-				sessionData.PLATFORM.isAST_1_6 = true ;
-				sessionData.PLATFORM.isAST_1_6_1 = true ;
+
+				/* add video codecs for 1.6 platforms */
+			}
+		}
+	},
+
+	parseVersion: function(ver) {
+		sessionData.AsteriskVersion = '';
+		sessionData.AsteriskBranch = '';
+		sessionData.AsteriskSVNRevision = 0;
+		if (ver.match(/SVN-(.*)-r(\d+)/i)) {
+			sessionData.AsteriskBranch = RegExp.$1;
+			sessionData.AsteriskSVNRevision = RegExp.$2;
+		}
+		if (ver.match(/SVN-trunk/i)) {
+			sessionData.AsteriskVersion = '1.8';
+		}
+		if (ver.match(/SVN-.*-([\d\.]+)-/i) || (ver.match(/\./) && ver.match(/([\d\.]+)/i))) {
+			sessionData.AsteriskVersion = RegExp.$1;
+		}
+		if (!sessionData.AsteriskBranch && sessionData.AsteriskVersion) {
+			var p = sessionData.AsteriskVersion.split('.');
+			sessionData.AsteriskBranch = p[0];
+			if (p.length > 1){
+				sessionData.AsteriskBranch += '.' + p[1];
+				if (p[0] == 1 && p[1] == 6) {
+					if (p.length > 2){
+						sessionData.AsteriskBranch += '.' + p[2];
+					}
+				}
 			}
 		}
 	},
@@ -197,7 +220,7 @@ var onLogInFunctions = {
 			}
 		}
 
-		if( sessionData.PLATFORM.isAST_1_6 ){ // make sure all the required upload paths are there
+		if (ASTGUI.version.gteq("1.6.0")) { // make sure all the required upload paths are there
 			u.clearActions();
 			var pu = false;
 			if(!http_conf.hasOwnProperty('post_mappings') ){
@@ -228,7 +251,7 @@ var onLogInFunctions = {
 		u.callActions();
 		top.cookies.set( 'rwaccess' , 'yes' );
 
-		if( sessionData.PLATFORM.isAST_1_6 ){
+		if (ASTGUI.version.gteq("1.6.0")) {
 			// make sure originate privilege is defined in asterisk 1.6
 			// This was introduced in Asterisk 1.6 and users upgrading from 1.4 do not have this
 			var tmp_managerUser = top.cookies.get('username') ;
@@ -239,6 +262,8 @@ var onLogInFunctions = {
 					var u = new listOfSynActions('manager.conf');
 					u.new_action( 'update', tmp_managerUser, 'write', write_value + ',originate' , write_value );
 					u.callActions();
+					var retval = ASTGUI.cliCommand('manager reload');
+					miscFunctions.logoutFunction.doLogout();
 					return 'manager_updated'; // about to reload
 				}
 			}
@@ -289,7 +314,7 @@ var onLogInFunctions = {
 		sessionData.directories.MOH = sessionData.directories.astdatadir + 'moh/' ; // path for music on hold files
 		sessionData.directories.menusRecord = sessionData.directories.Sounds + 'record/' ;
 
-		sessionData.directories.scripts = sessionData.directories.astdatadir + 'scripts/';/* Directory for gui scripts (listfiles, for example) */	
+		sessionData.directories.scripts = sessionData.directories.astdatadir + 'scripts/';/* Directory for gui scripts (listfiles, for example) */
 		sessionData.directories.output_SysInfo = 'tmp/sysinfo_output.html' ;
 		sessionData.directories.voicemails_dir = sessionData.directories.astspooldir + 'voicemail/default/' ;
 		sessionData.directories.script_takeBackup =  'sh ' + sessionData.directories.scripts + 'takebackup';
@@ -331,11 +356,11 @@ var onLogInFunctions = {
 				ASTGUI.dialog.alertmsg('The GUI does not have necessary privileges. <BR> Please check the manager permissions for the user !');
 				return;
 			}
-			if( crwp == 'postmappings_updated' || crwp == 'manager_updated' ){
+			if( crwp == 'postmappings_updated' ){
 				parent.ASTGUI.dialog.waitWhile(' reloading asterisk ... ');
 				var t = ASTGUI.cliCommand('reload') ;
 				setTimeout( function(){ 
-					if( sessionData.PLATFORM.isAST_1_6 ){
+					if (ASTGUI.version.gteq("1.6.0")) {
 						alert('                          Config files updated. '
 							+ '\n' + ' Please stop Asterisk and Start over for the changes to take effect' );
 					}
@@ -551,7 +576,7 @@ var onLogInFunctions = {
 		}
 
 		//if( sessionData.PLATFORM.isAA50  ){
-			DOM_mainscreen.src = 'home.html?status=0';
+			DOM_mainscreen.src = 'home.html?status=1';
 		//}
 
 		if( sessionData.PLATFORM.isAA50 && sessionData.PLATFORM.AA50_SKU.contains('800') ){
@@ -560,7 +585,28 @@ var onLogInFunctions = {
 			readcfg.dahdiScanConf();
 		}
 
+		onLogInFunctions.checkTrunks();
+
 		miscFunctions.show_advancedMode();
+	},
+	checkTrunks: function(){
+		var trunklist = pbx.trunks.list({analog: true, bri: true, pri: true});
+		
+		trunklist.each(function(trunk){
+			var ded_group = parent.pbx.trunks.getDedicatedGroup(parent.pbx.trunks.getName(trunk));
+			if(!(/^[\d\,]+$/.test(ded_group))){
+				var new_ded_group = parent.pbx.trunks.makeDedicatedGroup();
+				parent.sessionData.pbxinfo.trunks[type][trunk]['group'] = new_ded_group;
+				var x = new listOfSynActions('users.conf');
+				x.new_action('update', trunk, 'group', new_ded_group);
+				x.callActions();
+				ded_group = new_ded_group;
+			}
+			var x = new listOfSynActions('extensions.conf');
+			x.new_action('update', 'globals', trunk, 'DAHDI/g' + ded_group);
+			x.new_action('update', 'globals', 'group_' + ded_group, 'DAHDI/g' + ded_group);
+			x.callActions();
+		});
 	}
 };
 
@@ -662,7 +708,7 @@ var miscFunctions = {
 			ASTGUI.updateaValue({ file: ASTGUI.globals.configfile , context :'general', variable :'config_gui_version', value : sessionData.gui_version });
 		}
 		var u = _$('applyChanges_Button');
-		if (sessionData.PLATFORM.isAST_1_4) {
+		if (ASTGUI.version.lt("1.6.0")) {
 			var t = ASTGUI.cliCommand('reload') ;
 		} else {
 			var t = ASTGUI.cliCommand('module reload');
@@ -1116,8 +1162,8 @@ var after_localajaxinit = function(){
 		 * both commas and pipes aren't supported, such as when
 		 * doing time intervals for includes :-/
 		 * */
-		if (!sessionData.PLATFORM.isAST_1_6) {
-			top.session.delimiter = ',';
+		if (ASTGUI.version.lt("1.6.0")) {
+			top.session.delimiter = '|';
 		}
 	};
 
