@@ -3,9 +3,11 @@
  *
  * core parsing functions used in index.html
  *
- * Copyright (C) 2006-2008, Digium, Inc.
+ * Copyright (C) 2006-2011, Digium, Inc.
  *
  * Pari Nannapaneni <pari@digium.com>
+ * Ryan Brindley <rbrindley@digium.com>
+ * Erin Spiceland <espiceland@digium.com>
  *
  * See http://www.asterisk.org for more information about
  * the Asterisk project. Please do not directly contact
@@ -87,23 +89,29 @@ readcfg = {	// place where we tell the framework how and what to parse/read from
 					'exten=play_file,n,Playback(${var1})',
 					'exten=play_file,n,Hangup'
 				];
-				if (sessionData.PLATFORM.isAST_1_6) {
+				if (ASTGUI.version.gteq("1.6.0")) {
 					check_For_Contexts[ASTGUI.contexts.guitools][4] = 'exten=record_vmenu,n,Record(${var1},0,500,k)';
 				}
 		
+				check_For_Contexts[ 'macro-' + ASTGUI.contexts.localcrcid ] = [
+					'exten=s,1,Set(CALLERID(all)=${IF($[${LEN(${ARG4})} > 2]?${ARG4}:)})',
+					'exten=s,n,Goto(${ARG1},${ARG2},${ARG3})'
+				];
 				check_For_Contexts[ 'macro-' + ASTGUI.contexts.dialtrunks ] = [
-					// "; Macro by =  Brandon Kruse <bkruse@digium.com> & Matthew O'Gorman mogorman@digium.com",
+					// "; Macro by =  Brandon Kruse, Matthew O'Gorman, & Erin Spiceland <espiceland@digium.com>",
 					'exten=s,1,GotoIf($[${LEN(${FMCIDNUM})} > 6]?1-fmsetcid,1)',
-					'exten=s,2,GotoIf($[${LEN(${GLOBAL_OUTBOUNDCIDNAME})} > 1]?1-setgbobname,1)',
-					'exten=s,3,Set(CALLERID(num)=${IF($[${LEN(${CID_${CALLERID(num)}})} > 2]?${CID_${CALLERID(num)}}:)})',
+					'exten=s,n,GotoIf($[${LEN(${GLOBAL_OUTBOUNDCIDNAME})} > 1]?1-setgbobname,1)',
+					'exten=s,n,Set(CALLERID(num)=${IF($[${LEN(${CID_${CALLERID(num)}})} > 2]?${CID_${CALLERID(num)}}:)})',
+					'exten=s,n,Set(CALLERID(all)=${IF($[${LEN(${ARG5})} > 2]?${ARG5}:)})',
 					'exten=s,n,GotoIf($[${LEN(${CALLERID(num)})} > 6]?1-dial,1)',
 					'exten=s,n,Set(CALLERID(all)=${IF($[${LEN(${CID_${ARG3}})} > 6]?${CID_${ARG3}}:${GLOBAL_OUTBOUNDCID})})',
+					'exten=s,n,Set(CALLERID(all)=${IF($[${LEN(${ARG5})} > 2]?${ARG5}:)})',
 					'exten=s,n,Goto(1-dial,1)',
 					'exten=1-setgbobname,1,Set(CALLERID(name)=${GLOBAL_OUTBOUNDCIDNAME})',
 					'exten=1-setgbobname,n,Goto(s,3)',
 					'exten=1-fmsetcid,1,Set(CALLERID(num)=${FMCIDNUM})',
 					'exten=1-fmsetcid,n,Set(CALLERID(name)=${FMCIDNAME})',
-					'exten=1-fmsetcid,n,Goto(1-dial,1)',
+					'exten=1-fmsetcid,n,Goto(s,4)',
 					'exten=1-dial,1,Dial(${ARG1})',
 					'exten=1-dial,n,Gotoif(${LEN(${ARG2})} > 0 ?1-${DIALSTATUS},1:1-out,1)',
 					'exten=1-CHANUNAVAIL,1,Dial(${ARG2})',
@@ -185,7 +193,7 @@ readcfg = {	// place where we tell the framework how and what to parse/read from
 				ASTGUI.systemCmd( sessionData.directories.script_detectdahdi , function(){
 					setTimeout( function(){
 						if( sessionData.DEBUG_MODE ){
-							alert(ASTGUI.globals.dahdiIncludeFile + 'not found, ran script ' + sessionData.directories.script_detectdahdi + ' \n Click OK to Reload');
+							alert(ASTGUI.globals.dahdiIncludeFile + ' not found, ran script ' + sessionData.directories.script_detectdahdi + ' \n Click OK to Reload');
 						}
 						window.location.reload();
 					} , 500 );
@@ -207,9 +215,9 @@ readcfg = {	// place where we tell the framework how and what to parse/read from
 				sessionData.continueParsing = false ;
 				ASTGUI.systemCmd( sessionData.directories.app_dahdi_genconf , function(){
 					if( sessionData.DEBUG_MODE ){
-						alert( 'ran ' + sessionData.directories.app_dahdi_genconf + ' \n Click OK to Reload' );
+						alert( 'Error reading ' + ASTGUI.globals.dahdiIncludeFile + ': ' + s + 'Ran ' + sessionData.directories.app_dahdi_genconf + '. Click OK to Reload' );
 					}
-					window.location.reload() ;
+					window.location.reload();
 				});
 				return;
 			}else{
@@ -236,7 +244,7 @@ readcfg = {	// place where we tell the framework how and what to parse/read from
 					ASTGUI.miscFunctions.createConfig('applyzap.conf', function(){});
 
 					/* setup applyzap's basics */
-					var apply_zap = listofSynActions('applyzap.conf');
+					var apply_zap = listOfSynActions('applyzap.conf');
 					apply_zap.new_action('delcat', 'general', '', '');
 					apply_zap.new_action('newcat', 'general', '', '');
 
@@ -307,10 +315,16 @@ readcfg = {	// place where we tell the framework how and what to parse/read from
 		}else{
 			sessionData.GUI_PREFERENCES = gp['general'] ;
 		}
+		if(!sessionData.GUI_PREFERENCES.getProperty('disable_extension_ranges')){
+			var u = new listOfSynActions(ASTGUI.globals.configfile) ;
+			u.new_action('append', 'general', 'disable_extension_ranges', 'no');
+			u.callActions();
+		}
 		sessionData.continueParsing = true ;
 	}, // end of readcfg.guiPreferencesConf();
 
 	ExtensionsConf: function(){ //readcfg.ExtensionsConf();
+		pbx.queues.agents.setup();
 		var c = config2json({filename:'extensions.conf', usf:0});
 		//	look for numberplans, voicemenus, DID_trunk_x (incoming rules), timebasedrules, ringgroups, 
 		//	and store the information in the following objects
@@ -573,9 +587,15 @@ readcfg = {	// place where we tell the framework how and what to parse/read from
 				if (c[d].hasOwnProperty('zapchan') && sessionData.PLATFORM.isABE) {
 					users_conf.new_action('delete', d, 'zapchan', '');
 					users_conf.new_action('append', d, 'dahdichan', c[d]['zapchan']);
+					c[d]['dahdichan'] = c[d]['zapchan'];
 				}
 				if (!c[d].hasOwnProperty('type')) {
 					users_conf.new_action('append', d, 'type', 'peer');
+					c[d]['type'] = 'peer';
+				}
+				if (!c[d].hasOwnProperty('callcounter')) {
+					users_conf.new_action('append', d, 'callcounter', 'yes');
+					c[d]['callcounter'] = 'yes';
 				}
 				sessionData.pbxinfo['users'][d] = c[d];
 				continue;
@@ -919,7 +939,7 @@ astgui_managetrunks  = { // all the functions related to managing trunks would r
 	},
 
 	addAnalogTrunk: function(tr, cbf){ // creates a new analog trunk with the details metioned in tr object, cbf is callback function
-		// usage:: astgui_managetrunks.addAnalogTrunk({ 'zapchan':'2,3,4' , (optional) trunkname:'Ports 2,3,4'} , cbf) ;
+		// usage:: astgui_managetrunks.addAnalogTrunk({ 'zapchan':'2,3,4' , (optional) trunkname:'Ports 2,3,4', (optional) group: '1,2,3'} , cbf) ;
 
 		if( !tr.hasOwnProperty('zapchan') &&  !tr.hasOwnProperty('dahdichan') ){return false;} // zapchan is a required parameter. 
 
@@ -931,9 +951,18 @@ astgui_managetrunks  = { // all the functions related to managing trunks would r
 			var TMP_CHANNELS = tr.dahdichan ;
 			delete tr.dahdichan ;
 		}
-
+		
 		var trunk = astgui_managetrunks.misc.nextAvailableTrunk_x();
-		var group = astgui_managetrunks.misc.nextAvailableGroup();
+		var newgroup = astgui_managetrunks.misc.nextAvailableGroup();
+		var group = '';
+		if( tr.hasOwnProperty('group') ){
+			group = tr.group;
+			if(group.indexOf("New") > -1){
+				group.replace(/New/, newgroup);
+			}
+		}else{
+			group = newgroup;
+		}
 		var ct = ASTGUI.contexts.TrunkDIDPrefix + trunk;
 		// there are no incoming rules for analog trunks - there is only one catch all rule
 		// we only add the fallback extension "exten=s,3,..."  in incoming rules  Ex: 'exten = s,3,Goto(default|6000|1)' 
@@ -1592,7 +1621,7 @@ astgui_manageConferences = {
 			if(!line.beginsWith('exten=') ){ return;}
 			var b = ASTGUI.parseContextLine.getExten(line) ;
 			var configOptions = line.afterChar('=');
-			var params = configOptions.betweenXY('|',')');
+			var params = configOptions.split("${EXTEN}")[1].betweenXY('|',')');
 			if( params.contains('a') &&  params.contains('A') ) { // if is a meetMe Admin Login
 				b = ASTGUI.parseContextLine.getArgs(line)[0] ;
 			}
