@@ -3,7 +3,7 @@
  *
  * Core objects and utilities for their configs
  *
- * Copyright (C) 2006-2008, Digium, Inc.
+ * Copyright (C) 2006-2010, Digium, Inc.
  *
  * Ryan Brindley <ryan@digium.com>
  *
@@ -243,7 +243,7 @@ pbx.conferences.load = function() {
 		var name = line.betweenXY('=',',');
 		name = name.trim();
 
-		if(!sessionData.pbxinfo.hasOwnProperty(name)) {
+		if(!sessionData.pbxinfo.conferences.hasOwnProperty(name)) {
 			sessionData.pbxinfo.conferences[name] = new ASTGUI.customObject;
 			sessionData.pbxinfo.conferences[name]['configOptions'] = '';
 		}
@@ -673,6 +673,8 @@ pbx.queues.load = function() {
 		return true;
 	}
 
+	sessionData.pbxinfo.queues = new ASTGUI.customObject;
+	
 	cxt.each(function(line) {
 		if (!line.beginsWith('exten=')) {
 			return;
@@ -688,8 +690,95 @@ pbx.queues.load = function() {
 		sessionData.pbxinfo.queues[exten]['configLine'] = config;
 	});
 
+	var exten_globals = context2json({filename: 'extensions.conf', context: 'globals', usf:0});
+	sessionData.pbxinfo.queues_list = exten_globals[exten_globals.indexOfLike('QUEUES')].afterChar('=');
+
 	return true;
 };
+
+pbx.queues.agents = {};
+
+pbx.queues.agents.setup = function() {
+	//set up extensions.conf
+	var extensions_changes = {
+		'queue-member-manager' : [
+			'handle_member,1,Verbose(2, Looping through queues to log in or out queue members)',
+			'handle_member,n,Set(thisActiveMember=${CHANNEL(channeltype)}/${CHANNEL(peername)})',
+			'handle_member,n,Set(queue_field=2)',
+			'handle_member,n,Set(thisQueueXtn=${CUT(QUEUES,\\,,${queue_field})})',
+			'handle_member,n,While($[${EXISTS(${thisQueueXtn})}])',
+			'handle_member,n,Macro(member-loginlogout)',
+			'handle_member,n,Set(queue_field=$[${queue_field} + 1])',
+			'handle_member,n,Set(thisQueueXtn=${CUT(QUEUES,\\,,${queue_field})})',
+			'handle_member,n,EndWhile()'
+		],
+		'macro-member-loginlogout' : [
+			's,1,Verbose(2, Logging queue member in or out of the request queue)',
+			's,n,Set(thisQueue=${thisQueueXtn})',
+			's,n,Set(queueMembers=${QUEUE_MEMBER_LIST(${thisQueue})})',
+			's,n,Set(field=1)',
+			's,n,Set(logged_in=0)',
+			's,n,Set(thisQueueMember=${CUT(queueMembers,\\,,${field})})',
+			's,n,While($[${EXISTS(${thisQueueMember})}])',
+			's,n,GotoIf($["${thisQueueMember}" != "${thisActiveMember}"]?check_next)',
+			's,n,Set(logged_in=1)',
+			's,n,ExitWhile()',
+			's,n(check_next),Set(field=$[${field} + 1])',
+			's,n,Set(thisQueueMember=${CUT(queueMembers,\\,,${field})})',
+			's,n,EndWhile()',
+			's,n,MacroIf($[${logged_in} = 0]?q_login:q_logout)'
+		],
+		'macro-q_login' : [
+			's,1,Verbose(2, Logging ${thisActiveMember} into the ${thisQueue} queue)',
+			's,n,AddQueueMember(${thisQueue},${thisActiveMember})',
+			's,n,Playback(silence/1)',
+			's,n,ExecIf($["${AQMSTATUS}" = "ADDED"]?Playback(agent-loginok):Playback(an-error-has-occurred))'
+		],
+		'macro-q_logout' : [
+			's,1,Verbose(2, Logged ${thisActiveMember} out of ${thisQueue} queue)',
+			's,n,RemoveQueueMember(${thisQueue},${thisActiveMember})',
+			's,n,Playback(silence/1)',
+			's,n,ExecIf($["${RQMSTATUS}" = "REMOVED"]?Playback(agent-loggedoff):Playback(an-error-has-occurred))'
+		]
+	};
+	var sip_changes = {
+		'general' : {
+			'subscribecontext' : ASTGUI.contexts.subscribe
+		}
+	};
+
+	var extensions_conf = listOfSynActions('extensions.conf');
+	var extensconfig = config2json({filename: 'extensions.conf', usf:0});
+	for (var cxt_name in extensions_changes) {
+		if (!extensions_changes.hasOwnProperty(cxt_name) || extensconfig.hasOwnProperty(cxt_name)) {
+			continue;
+		}
+
+		extensions_conf.new_action('newcat', cxt_name, '', '');
+		extensconfig[cxt_name] = extensions_changes[cxt_name];
+
+		var cxt = extensions_changes[cxt_name];
+		for (var i=0; i<cxt.length; i++) {
+			var prop = cxt[i];
+			extensions_conf.new_action('append', cxt_name, 'exten', prop);
+		}
+
+		extensions_conf.callActions();
+		extensions_conf.clearActions();
+	}
+	if (!extensconfig['globals'].indexOfLike('QUEUES')) {
+		extensions_conf.new_action('append', 'globals', 'QUEUES', '');
+		extensions_conf.callActions();
+		extensions_conf.clearActions();
+	}
+
+	var sip_conf = listOfSynActions('sip.conf');
+	var sipconfig = config2json({filename: 'sip.conf', usf:1});
+	if (!sipconfig['general'].hasOwnProperty('subscribecontext')) {
+		sip_conf.new_action('append', 'general', 'subscribecontext', sip_changes['general']['subscribecontext']);
+	}
+	sip_conf.callActions();
+};
 /*---------------------------------------------------------------------------*/
 
 /*---------------------------------------------------------------------------*/
@@ -1234,6 +1323,118 @@ pbx.trunks = {
 	tech: {analog: 'DAHDI', bri: 'DAHDI', iax: 'IAX2', pri:'DAHDI', sip: 'SIP'}
 };
 
+pbx.trunks.getTrunkIdByName = function(name) {
+	if(name.indexOf('group_' > -1)){
+		var group = name.replace("group_","");
+		var g = this.getTrunkNamesByGroup(group);
+		name = g[0] ? g[0] : name;
+	}
+	var t = this.list();
+	var res = '';
+	t.each(function(item){
+		var type = pbx.trunks.getType(item);
+		if(parent.sessionData.pbxinfo.trunks[type][item]['trunkname'] == name || item == name){
+			res = item;
+		}
+	});
+	return res;
+};
+
+pbx.trunks.getTrunkNamesByGroup = function(group) {
+	var t = this.list({analog: true});
+	var a = [];
+	t.each(function(item){
+		var type = parent.pbx.trunks.getType(item);
+		try{
+			var g = parent.sessionData.pbxinfo.trunks[type][item]['group'].toString().split(',');
+			g.each(function(h){
+				if(h == group){
+					var name = parent.sessionData.pbxinfo.trunks[type][item]['trunkname'];
+					if(!a.contains(name)){
+						a.push(parent.sessionData.pbxinfo.trunks[type][item]['trunkname']);
+					}
+				}
+			});
+		}catch(e){}
+	});
+	return a.sort();
+};
+
+pbx.trunks.getGroupDescription = function(group){
+	var tr = parent.pbx.trunks.getTrunkNamesByGroup(group);
+	var trstr = tr.join(", ");
+	if (trstr.length > 30){
+		trstr = trstr.substr(30) + '...';
+	}
+	return "Group " + group + " (" + trstr + ")";
+};
+
+pbx.trunks.getDedicatedGroup = function(trunk) {
+	var g = this.listAllGroups();
+	var cur = [];
+	var ded_group = '';
+	g.each(function(group){
+		if(ded_group) { return ded_group; }
+		var t = parent.pbx.trunks.getTrunkNamesByGroup(group);
+		var abort = false;
+		t.each(function(eachtrunk){
+			if(!abort){
+				if(trunk == eachtrunk){
+					ded_group = group;
+					g.push(group);
+				}else{
+					if(ded_group == group){
+						ded_group = '';
+					}
+					abort = true;
+				}
+			}
+		});
+	});
+	return ded_group;
+}
+
+pbx.trunks.makeDedicatedGroup = function() {
+	var newgroup = this.nextAvailGroup();
+	var ext_conf = new listOfSynActions('extensions.conf');
+	ext_conf.new_action('update', 'globals', 'group_' + newgroup, 'DAHDI/g' + newgroup);
+	ext_conf.callActions();
+	return newgroup;
+};
+
+pbx.trunks.listAllGroups = function() {
+	var t = this.list({analog: true});
+	var a = [];
+	t.each(function(item){
+		var type = parent.pbx.trunks.getType(item);
+		try{ var g = parent.sessionData.pbxinfo.trunks[type][item]['group'].toString().split(','); 
+			g.each(function(h){
+				if(!a.contains(h)){
+					a.push(h);
+				}
+			});
+		} catch(e){}
+	});
+	return a.sort();
+};
+
+pbx.trunks.formatGroupString = function(group) {
+	var newgroup = this.nextAvailGroup();
+	var oldgroups = group.split(",");
+	// when creating a new group and a dedicated group at the same time,
+	// use the same group for both and don't duplicate it.
+	for(var i = 0; i < oldgroups.length; i++){
+		if (oldgroups[i] == newgroup){ return group; }
+	}
+	if(group.indexOf('New') > -1){
+		var ext_conf = new listOfSynActions('extensions.conf');
+		ext_conf.new_action('update', 'globals', 'group_' + newgroup, 'DAHDI/g' + newgroup);
+		ext_conf.callActions();
+		group = group.replace('New', newgroup);
+	}
+	return group ? group : newgroup;
+};
+
 /**
  * Add a trunk.
  * @param type type of trunk.
@@ -1263,7 +1464,9 @@ pbx.trunks.add = function(type, trunk, callback, basis) {
 		delete trunk.dahdichan;
 
 		name = this.nextAvailTrunk();
-		group = this.nextAvailGroup();
+		if (trunk.hasOwnProperty('group')) {
+			group = trunk.group;
+		}
 
 		delete trunk.signalling;
 		delete trunk.channel;
@@ -1305,7 +1508,6 @@ pbx.trunks.add = function(type, trunk, callback, basis) {
 	trunk.allow = 'all';
 	trunk.context = ct || '';
 	trunk.disallow = 'all';
-	trunk.group = group || null;
 	trunk.hasexten = 'no';
 	trunk.hasiax = (type === 'iax') ? 'yes' : 'no';
 	trunk.hassip = (type === 'sip') ? 'yes' : 'no';
@@ -1329,7 +1531,9 @@ pbx.trunks.add = function(type, trunk, callback, basis) {
 		}
 
 		top.sessionData.pbxinfo.trunks[type][name][v] = trunk[v];
-		users_conf.new_action('append', name, v, trunk[v]);
+		if(v != null){
+			users_conf.new_action('append', name, v, trunk[v]);
+		}
 	}
 	top.sessionData.pbxinfo.trunks[type][name]['disallow'] = trunk['disallow'];
 	users_conf.new_action('append', name, 'disallow', trunk['disallow']);
@@ -1345,6 +1549,16 @@ pbx.trunks.add = function(type, trunk, callback, basis) {
 			users_conf.new_action('append', name, 'signalling', sg);
 			users_conf.new_action('append', name, 'channel', ch);
 		});
+		if(!group || group.toString().indexOf(',') > 0){
+			group = this.getDedicatedGroup(name);
+			if(!group){
+				group = this.makeDedicatedGroup();
+			}
+		}
+		trunk.group = group;
+	}
+	if(group){
+		users_conf.new_action('append', name, 'group', group);
 	}
 
 	/* TODO: get listOfActions to return a response so we know everythings ok! */
@@ -1357,9 +1571,12 @@ pbx.trunks.add = function(type, trunk, callback, basis) {
 	ext_conf.new_action('newcat', ct, '', '');
 	ext_conf.new_action('delcat', ct + ASTGUI.contexts.TrunkDefaultSuffix, '' ,'');
 	ext_conf.new_action('newcat', ct + ASTGUI.contexts.TrunkDefaultSuffix, '', '');
+	ext_conf.callActions();
+	ext_conf.clearActions();
 	ext_conf.new_action('append', ct, 'include', ct + ASTGUI.contexts.TrunkDefaultSuffix);
 	/* not going to work for analog vv */
-	ext_conf.new_action('update', 'globals', name, tech + '/' + ((type === 'analog')? group : name));
+	ext_conf.new_action('update', 'globals', name, tech + '/' + ((type === 'analog') ? 'g' + group : name));
+
 
 	resp = '';
 	resp = ext_conf.callActions();
@@ -1382,6 +1599,16 @@ pbx.trunks.add = function(type, trunk, callback, basis) {
 	return true;
 };
 
+pbx.trunks.isAnalog = function(trunk) {
+	if(trunk.indexOf("group_" == -1)){
+		var type = this.getType(trunk);
+		if(type == 'analog'){
+			return true;
+		}
+	}
+	return false;
+};
+
 /**
  * Get Trunk Details.
  * @param trunk
@@ -1429,6 +1656,19 @@ pbx.trunks.getName = function(trunk) {
 		return trunk;
 	}
 
+	/* if we got passed a group somehow, see if it's a dedicated group. 
+	If it is, we can get that trunk's name. */
+	if (trunk.indexOf("group_") > -1){
+		trunk = trunk.replace("group_","");
+		var tr = this.getTrunkNamesByGroup(trunk);
+		if(tr.length == 1){
+			return tr[0];
+		}else{
+			top.log.error("group_" + trunk + "describes multiple trunks. I don't know which one's name you want!");
+			return null;
+		}
+	}
+
 	for (var i=0; i < this.trunk_types.length; i++) {
 		if (sessionData.pbxinfo.trunks[this.trunk_types[i]][trunk]) {
 			if (this.trunk_types[i] === 'bri' && sessionData.pbxinfo.trunks[this.trunk_types[i]][trunk].trunkname) {
@@ -1438,8 +1678,8 @@ pbx.trunks.getName = function(trunk) {
 		}
 	}
 
-	top.log.warn('pbx.trunks.getType: No trunk name found.');
-	top.log.warn('pbx.trunks.getType: Trunk, ' + trunk + ', most like doesn\'t exist');
+	top.log.warn('pbx.trunks.getName: No trunk name found.');
+	top.log.warn('pbx.trunks.getName: Trunk, ' + trunk + ', most likely doesn\'t exist');
 	return null;
 };
 
@@ -1472,6 +1712,9 @@ pbx.trunks.getProviderType = function(trunk) {
  * @return type of trunk.
  */
 pbx.trunks.getType = function(trunk) {
+	if(trunk.indexOf("group_") > -1){
+		return "group";
+	}
 	for (var i=0; i < this.trunk_types.length; i++) {
 		if (sessionData.pbxinfo.trunks[this.trunk_types[i]][trunk]) {
 			return this.trunk_types[i];
@@ -1540,19 +1783,24 @@ pbx.trunks.list = function(types) {
  */
 pbx.trunks.nextAvailGroup = function() {
 	var nums = [];
-	var trunks = this.list({analog: true, pri: true});
-	var type = 'analog';
+	var trunks = this.list({analog: true, bri: true, pri: true});
 
 	if (!trunks.length) {
 		top.log.warn('pbx.trunks.nextAvailGroup: no trunks');
 	}
 
-	trunks.each(function(trunk) {
-		type = (sessionData.pbxinfo.trunks['analog'].hasOwnProperty(trunk)) ? 'analog' : 'pri';
-		nums.push(sessionData.pbxinfo.trunks[type][trunk]['group']);
-	});
-
-	return nums.firstAvailable();
+	//trunks.each(function(trunk) {
+	for (var i = 0; i < trunks.length; i++){
+		trunk = trunks[i];
+		type = parent.pbx.trunks.getType(trunk);
+		try{
+			var g = sessionData.pbxinfo.trunks[type][trunk]['group'].toString().split(',');
+			for(var j = 0; j < g.length; j++){
+				nums.push(g[j]);
+			}
+		}catch(e){}
+	}
+	return nums.sort().firstAvailable();
 };
 
 /**
@@ -1585,6 +1833,7 @@ pbx.trunks.remove = function(trunk) {
 	var exts = config2json({filename: 'extensions.conf', usf:0});
 	var actions = new listOfSynActions('extensions.conf');
 	actions.new_action('delete', 'globals', trunk, '');
+	actions.new_action('delete', 'globals', "CID_" + trunk, '');
 
 	for (var ext in exts) {
 		if (!exts.hasOwnProperty(ext) || !ext.contains(ASTGUI.contexts.TrunkDIDPrefix + trunk)) {
@@ -1856,29 +2105,22 @@ pbx.users.add = function(exten, info, callback) {
 	x.filename('users.conf');
 	x.new_action('delcat', exten, '', '');
 	x.new_action('newcat', exten, '', '');
-	x.new_action('append', exten, 'username', exten);
-	x.new_action('append', exten, 'transfer', 'yes');
-	x.new_action('append', exten, 'disallow', disallow);
-	x.new_action('append', exten, 'allow', allow);
-	x.new_action('append', exten, 'mailbox', info.mailbox || exten);
-	x.new_action('append', exten, 'call-limit', '100');
-	x.new_action('append', exten, 'type', 'peer');
-
-	if (info.mailbox) {
-		delete info.mailbox;
-	}
-
-	if (info['call-limit']) {
-		delete info['call-limit'];
-	}
+	info['username'] = exten;
+	info['transfer'] = 'yes';
+	info['disallow'] = disallow;
+	info['allow'] = allow;
+	info['mailbox'] = info.mailbox || exten;
+	info['call-limit'] = '100';
+	info['type'] = 'peer';
+	info['callcounter'] = 'yes';
 
 	if (info.hasOwnProperty('hassip') && info['hassip'].isAstTrue()) {
-		x.new_action('append', exten, 'host', 'dynamic');
-		delete info['host'];
+		info['host'] = 'dynamic';
 	}
 
 	for (var prop in info) {
-		if (info.hasOwnProperty(prop)) {
+		if (prop != '' && !(info[prop] instanceof Function)) {
+			top.log.debug("adding " + prop + "=" + info[prop]);
 			x.new_action('append', exten, prop, info[prop]);
 		}
 	}
@@ -2250,10 +2492,11 @@ pbx.voice_menus.add = function(name, menu, callback) {
  * @return boolean of success.
  */
 pbx.voice_menus.remove = function(name) {
+	if(!name){ return false; }
 	var acts = new listOfSynActions('extensions.conf');
 	acts.new_action('delcat', name, '', '');
 
-	if (sessionData.pbxinfo.voicemenus[name]['alias_exten'] != '') {
+	if (sessionData.pbxinfo.voicemenus[name] && sessionData.pbxinfo.voicemenus[name]['alias_exten'] != '') {
 		var aext = sessionData.pbxinfo.voicemenus[name]['alias_exten'].lChop('exten=');
 		acts.new_action('delete', ASTGUI.contexts.VoiceMenuExtensions, 'exten', '', aext);
 		acts.new_action('delete', 'default', 'exten', '', aext); /* backward compatibility with gui 1.x */
@@ -2290,6 +2533,6 @@ pbx.voice_menus.next = function() {
 /*---------------------------------------------------------------------------*/
 
 var checkForNames = function(name, users_conf) {
-	var users_conf = users_conf || config2json({ filename: 'user.conf', usf: 0});
+	var users_conf = users_conf || config2json({ filename: 'users.conf', usf: 0});
 	return users_conf.hasOwnProperty(name) ? false : true;
 };
