@@ -254,6 +254,7 @@ var edit_VOIPTrunk_save_go = function(){
 			}else{
 				if( parent.sessionData.pbxinfo.trunks[ttype][EDIT_TRUNK].hasOwnProperty('fromdomain') ){
 					delete parent.sessionData.pbxinfo.trunks[ttype][EDIT_TRUNK]['fromdomain'] ;
+					x.new_action('delete', EDIT_TRUNK , 'fromdomain' );
 				}
 			}
 	
@@ -264,16 +265,18 @@ var edit_VOIPTrunk_save_go = function(){
 			}else{
 				if( parent.sessionData.pbxinfo.trunks[ttype][EDIT_TRUNK].hasOwnProperty('fromuser') ){
 					delete parent.sessionData.pbxinfo.trunks[ttype][EDIT_TRUNK]['fromuser'] ;
+					x.new_action('delete', EDIT_TRUNK , 'fromuser' );
 				}
 			}
 
-			var tmp_authuser = ASTGUI.getFieldValue('trunk_authuser') ;
+			var tmp_authuser = ASTGUI.getFieldValue('trunk_authuser');
 			if( tmp_authuser ){
 				x.new_action('update', EDIT_TRUNK , 'authuser', tmp_authuser );
 				parent.sessionData.pbxinfo.trunks[ttype][EDIT_TRUNK]['authuser'] = tmp_authuser ;
 			}else{
 				if( parent.sessionData.pbxinfo.trunks[ttype][EDIT_TRUNK].hasOwnProperty('authuser') ){
 					delete parent.sessionData.pbxinfo.trunks[ttype][EDIT_TRUNK]['authuser'] ;
+					x.new_action('delete', EDIT_TRUNK , 'authuser' );
 				}
 			}
 
